@@ -36,7 +36,7 @@ class Trajectory(Path):
         super(Trajectory, self).__init__()
         self.steps = steps
         self.dt = dt
-        self.t = []
+        self.t = np.arange(steps) * dt
         self.v = []
         self.a = []
         self.steer = []
@@ -49,6 +49,7 @@ class Trajectory(Path):
     def from_trajectory_array(cls, trajectory_array: np.ndarray, dt, calc_derivative: bool = False,
                               v0=0., heading0=0., a0=0., steer0=0., steer_velocity0=0.) -> 'Trajectory':
         '''
+        从x y点序列变换trajectory类，并且可以计算高阶导数
         trajectory_array: shape of [N,2], ndarray([[x,y],[x,y]])
         calc_derivative: if True, then calculate the Higher-order kinematics parameters
         todo: 以后要加入自定义vehicle model的接口
@@ -65,6 +66,10 @@ class Trajectory(Path):
             traj.y = list(ys)
         return traj
 
+    @property
+    def trajectory_array(self):
+        return np.column_stack((self.x, self.y))
+
     def densify(self):
         # 时间维度的
         pass
@@ -151,6 +156,15 @@ class FrenetTrajectory(Trajectory):
         super(FrenetTrajectory, self).clearState()
         self.clearFrenetState()
 
+    @classmethod
+    def from_sl_array(cls, sl_array, dt, calc_derivative=True):
+        pass
+        # todo: 想一想怎么用插值曲线的方式计算s和l的导数。三次样条插值的话，边界条件是个问题。
+
+    @property
+    def trajectory_sl_array(self):
+        return np.column_stack((self.s, self.l))
+
 
 if __name__ == '__main__':
     a = Trajectory(50)
